<center><img src="https://raw.githubusercontent.com/colav/colav.github.io/master/img/Logo.png"/></center>

# HunabKu template plugin 
This is a template for xyz project
replace template for the name of the plugin everiwhere.

# Description
Write something meaningful her ;)

# Installation

## Dependencies
What do I need fot this plugin, it could be external services etc..

## Package
Write here how to install this plugin
usauly is 

`pip install hunabku_template`

or

`pip install hunabku[template]`

# Usage
Should I know something is not is apidocs?
if yes, then put it here.

Additional parameters for hunabku in the config should be here as well.
example :

```
# myvar
# this is an example var
config.hunabku_template.Hello.Hello.myvar = "myvalue"

# port
# this is other way to set doc
config.hunabku_template.Hello.Hello.subcategory.port = 8099

# host
# 
config.hunabku_template.Hello.Hello.subcategory.host = "host"

```
Those parameters are not really needed in the condfig file, it is just for illustration.


# License
BSD-3-Clause License 

# Links
http://colav.udea.edu.co/



